@@ -1,3 +1,4 @@
+from bson.objectid import ObjectId
 from bson.codec_options import TypeRegistry, CodecOptions
 
 from .utils import classproperty
@@ -18,7 +19,21 @@ class Schema(BaseSchema):
   @property
   def reference(self):
     return Reference(self.__class__)(self._id)
-  
+
   @classproperty
-  def query(self):
-    return Query(model=self)
\ No newline at end of file
+  def query(cls):
+    return Query(model=cls)
+
+  @classmethod
+  def list(cls, **filter):
+    return cls.query.where(**filter).get()
+
+  @classmethod
+  def get(cls, document_id, **filter):
+    return cls.query.where(_id=ObjectId(document_id), **filter).get_one()
+
+  class Config:
+    json_encoders = {
+      ObjectId: lambda oid: str(oid),
+      Reference: lambda ref: str(ref)
+    }
\ No newline at end of file
